Arch enum

A dart compile exe --target-arch value.

Inheritance
Available extensions

Values

arm → const Arch
arm64 → const Arch
ia32 → const Arch
riscv32 → const Arch
riscv64 → const Arch
x64 → const Arch

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

current() Arch
fromName(String? name) Arch?

Constants

values → const List<Arch>
A constant List of the values in this enum, in order of their declaration.