models/build_settings_config library

Classes

BuildSettingsConfig
The build: section of revali.yaml. Its mere presence signals that revali build should compile a native executable via dart compile exe --target-os --target-arch, made available to build-type constructs through RevaliBuildContext.compiledExecutables.