models/compiled_executable library

Classes

CompiledExecutable
A native executable that revali build already compiled via dart compile exe --target-os --target-arch, made available to build-type constructs (e.g. revali_docker) so they can package it without compiling anything themselves.