debugInfoPath property
Absolute path to the split debug info file (dart compile exe -S),
when strip_debug_info was requested. Never null unless stripping
wasn't enabled for this build.
Implementation
final String? debugInfoPath;
Absolute path to the split debug info file (dart compile exe -S),
when strip_debug_info was requested. Never null unless stripping
wasn't enabled for this build.
final String? debugInfoPath;