AnyFile class

Implementers

Constructors

AnyFile({required String basename, String content = '', List<int>? bytes, String? extension, List<String> segments = const []})
const

Properties

basename → String
final
bytes → List<int>?
Binary content for this file. When non-null, the generator writes these bytes directly instead of writing content as text.
final
content → String
final
extension → String?
final
fileName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → List<String>
final
subFiles → List<AnyFile>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited