PartFile class final

Inheritance

Constructors

PartFile({required List<String> path, required String content})

Properties

basename String
finalinherited
bytes List<int>?
Binary content for this file. When non-null, the generator writes these bytes directly instead of writing content as text.
finalinherited
content String
no setteroverride
extension String?
finalinherited
fileName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
parent DartFile?
getter/setter pair
parts List<PartFile>
finalinherited
path List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<String>
finalinherited
subFiles List<AnyFile>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited