MetaToJson class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
paramCount
→ int
-
Number of
Object Function(T) closures the method expects, one per
class type parameter. 0 for the plain, non-generic toJson() shape.
final
-
returnType
→ MetaType
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited