RevaliConstructConfig class

Annotations
  • @JsonSerializable.new()

Constructors

RevaliConstructConfig({required String name, bool? enabled, String? package, Map<String, dynamic> options = const {}})
const
RevaliConstructConfig.fromJson(Map<String, dynamic> json)
factory

Properties

constructOptions → ConstructOptions
no setter
disabled → bool
no setter
enabled → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
options → Map<String, dynamic>
final
package → String?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited