RevaliYaml class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
RevaliYaml({required List<
RevaliConstructConfig> constructs, HotReloadConfig? hotReload, BuildSettingsConfig? build}) -
const
-
RevaliYaml.fromJson(Map<
String, dynamic> json) -
factory
- RevaliYaml.none()
-
const
Properties
- build → BuildSettingsConfig?
-
The
build:section. Its presence signals thatrevali buildshould compile a native executable — see BuildSettingsConfig.final -
constructs
→ List<
RevaliConstructConfig> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hotReload → HotReloadConfig?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
configFor(
ConstructMaker maker) → RevaliConstructConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited