BuildSettingsConfig class
The build: section of revali.yaml. Its mere presence signals that
revali build should compile a native executable via
dart compile exe --target-os --target-arch, made available to
build-type constructs through RevaliBuildContext.compiledExecutables.
- Annotations
-
- @JsonSerializable.new()
Constructors
-
BuildSettingsConfig({TargetOs? targetOs, List<
Arch> ? targetArch, bool stripDebugInfo = false}) -
const
-
BuildSettingsConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
resolvedTargetArch
→ List<
Arch> -
targetArch, defaulting to the host architecture when empty.
no setter
- resolvedTargetOs → TargetOs
-
targetOs, defaulting to the host OS when omitted.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - stripDebugInfo → bool
-
final
-
targetArch
→ List<
Arch> -
final
- targetOs → TargetOs?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited