CompiledExecutable class
A native executable that revali build already compiled via
dart compile exe --target-os --target-arch, made available to
build-type constructs (e.g. revali_docker) so they can package it
without compiling anything themselves.
Constructors
- CompiledExecutable({required TargetOs targetOs, required Arch targetArch, required String path, String? debugInfoPath})
-
const
Properties
- debugInfoPath → String?
-
Absolute path to the split debug info file (
dart compile exe -S), whenstrip_debug_infowas requested. Nevernullunless stripping wasn't enabled for this build.final - hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
Absolute path to the compiled executable on disk.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetArch → Arch
-
final
- targetOs → TargetOs
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited