RevaliBuildContext class
- Inheritance
-
- Object
- RevaliContext
- RevaliBuildContext
Constructors
-
RevaliBuildContext({required String? flavor, required Mode mode, required Map<
String, String> defines, List<CompiledExecutable> compiledExecutables = const []}) -
const
Properties
-
compiledExecutables
→ List<
CompiledExecutable> -
Executables
revali buildalready compiled for this build, if anytarget_os/target_archwas requested via thebuild:section ofrevali.yaml. Empty when no compilation was requested.final -
defines
→ Map<
String, String> -
final
- flavor → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → Mode
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited